==> nmrium-0.50.1.tgz: package/lib/component/hooks/usePanelPreferences.js <==
import has from 'lodash/has';
import { useMemo } from 'react';
import { getDefaultPredictionOptions } from '../../data/PredictionManager';
import { usePreferences } from '../context/PreferencesContext';
import { getIntegralDefaultValues, getPeaksDefaultValues, getZoneDefaultValues, getRangeDefaultValues, databaseDefaultValues, getMultipleSpectraAnalysisDefaultValues, getSpectraDefaultValues, } from '../reducer/preferences/panelsPreferencesDefaultValues';
import { getValue } from '../utility/LocalStorage';
const basePath = 'formatting.panels';
function getDefaultPreferences(panelKey, nucleus) {
    switch (panelKey) {
        case 'spectra':
            return getSpectraDefaultValues(nucleus);
        case 'peaks':
            return getPeaksDefaultValues(nucleus);
        case 'integrals':
            return getIntegralDefaultValues(nucleus);
        case 'ranges':
            return getRangeDefaultValues(nucleus);
        case 'zones':
            return getZoneDefaultValues(nucleus);
        case 'database':
            return databaseDefaultValues;
        case 'multipleSpectraAnalysis':
            return getMultipleSpectraAnalysisDefaultValues(nucleus);
        case 'prediction':
            return getDefaultPredictionOptions();
        default:
            return {};
    }
}
function joinWithNucleusPreferences(data, nucleus, returnOnlyNucleusPreferences = false) {
    const { nuclei = {}, ...rest } = data;
    if (returnOnlyNucleusPreferences) {
        return nuclei?.[nucleus];
    }
    return { ...nuclei[nucleus], ...rest };
}
function getPanelPreferences(preferences, panelKey, nucleus, returnOnlyNucleusPreferences = false) {
    const panelPath = `${basePath}.${panelKey}`;
    let path = panelPath;
    if (nucleus) {
        switch (panelKey) {
            case 'multipleSpectraAnalysis':
            case 'matrixGeneration':
                path = `${panelPath}.${nucleus}`;
                break;
            default:
                path = `${panelPath}.nuclei.${nucleus}`;
                break;
        }
    }
    let panelPreferences = {};
    if (has(preferences, path)) {
        panelPreferences = getValue(preferences, panelPath, {});
    }
    else {
        panelPreferences = getDefaultPreferences(panelKey, nucleus);
    }
    switch (panelKey) {
        case 'multipleSpectraAnalysis':
        case 'matrixGeneration':
            return nucleus ? panelPreferences[nucleus] : {};
        case 'database':
        case 'prediction':
            return panelPreferences;
        default:
            return nucleus
                ? joinWithNucleusPreferences(panelPreferences, nucleus, returnOnlyNucleusPreferences)
                : {};
    }
}
export function usePanelPreferences(panelKey, nucleus) {
    const { current } = usePreferences();
    return useMemo(() => {
        return getPanelPreferences(current, panelKey, nucleus);
    }, [current, nucleus, panelKey]);
}
export function usePanelPreferencesByNuclei(panelKey, nuclei) {
    const { current } = usePreferences();
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    const { nuclei: omitNuclei = null, ...restPreferences } = getPanelPreferences(current, panelKey);
    return useMemo(() => {
        return {
            nuclei: Object.fromEntries(nuclei.map((nucleusLabel) => [
                nucleusLabel,
                getPanelPreferences(current, panelKey, nucleusLabel, true),
            ])),
            ...restPreferences,
        };
    }, [current, nuclei, panelKey, restPreferences]);
}

==> nmrium-0.55.0.tgz: package/lib/component/hooks/usePanelPreferences.js <==
import has from 'lodash/has';
import { useMemo } from 'react';
import { getDefaultPredictionOptions } from '../../data/PredictionManager';
import { usePreferences } from '../context/PreferencesContext';
import { getIntegralDefaultValues, getPeaksDefaultValues, getZoneDefaultValues, getRangeDefaultValues, databaseDefaultValues, getMultipleSpectraAnalysisDefaultValues, getSpectraDefaultValues, } from '../reducer/preferences/panelsPreferencesDefaultValues';
import { getValue } from '../utility/LocalStorage';
function getDefaultPreferences(panelKey, nucleus) {
    switch (panelKey) {
        case 'spectra':
            return getSpectraDefaultValues(nucleus);
        case 'peaks':
            return getPeaksDefaultValues(nucleus);
        case 'integrals':
            return getIntegralDefaultValues(nucleus);
        case 'ranges':
            return getRangeDefaultValues(nucleus);
        case 'zones':
            return getZoneDefaultValues(nucleus);
        case 'database':
            return databaseDefaultValues;
        case 'multipleSpectraAnalysis':
            return getMultipleSpectraAnalysisDefaultValues(nucleus);
        case 'prediction':
            return getDefaultPredictionOptions();
        default:
            return {};
    }
}
function joinWithNucleusPreferences(data, nucleus, returnOnlyNucleusPreferences = false) {
    const { nuclei = {}, ...rest } = data;
    if (returnOnlyNucleusPreferences) {
        return nuclei?.[nucleus];
    }
    return { ...nuclei[nucleus], ...rest };
}
function getPanelPreferences(preferences, panelKey, nucleus, returnOnlyNucleusPreferences = false) {
    const panelPath = `panels.${panelKey}`;
    let path = panelPath;
    if (nucleus) {
        switch (panelKey) {
            case 'multipleSpectraAnalysis':
            case 'matrixGeneration':
                path = `${panelPath}.${nucleus}`;
                break;
            default:
                path = `${panelPath}.nuclei.${nucleus}`;
                break;
        }
    }
    let panelPreferences = {};
    if (has(preferences, path)) {
        panelPreferences = getValue(preferences, panelPath, {});
    }
    else {
        panelPreferences = getDefaultPreferences(panelKey, nucleus);
    }
    switch (panelKey) {
        case 'multipleSpectraAnalysis':
        case 'matrixGeneration':
            return nucleus ? panelPreferences[nucleus] : {};
        case 'database':
        case 'prediction':
            return panelPreferences;
        default:
            return nucleus
                ? joinWithNucleusPreferences(panelPreferences, nucleus, returnOnlyNucleusPreferences)
                : {};
    }
}
export function usePanelPreferences(panelKey, nucleus) {
    const { current } = usePreferences();
    return useMemo(() => {
        return getPanelPreferences(current, panelKey, nucleus);
    }, [current, nucleus, panelKey]);
}
export function usePanelPreferencesByNuclei(panelKey, nuclei) {
    const { current } = usePreferences();
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    const { nuclei: omitNuclei = null, ...restPreferences } = getPanelPreferences(current, panelKey);
    return useMemo(() => {
        return {
            nuclei: Object.fromEntries(nuclei.map((nucleusLabel) => [
                nucleusLabel,
                getPanelPreferences(current, panelKey, nucleusLabel, true),
            ])),
            ...restPreferences,
        };
    }, [current, nuclei, panelKey, restPreferences]);
}
